import 'bootstrap-datepicker';
import { Component, forwardRef, HostListener, Input, ViewChild, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { CommonModule } from '@angular/common';

var BASE_OPTION = ({
    autoclose: true,
    format: 'dd/mm/yyyy',
    language: 'en-GB'
});
var th_TH = (Object.assign({}, BASE_OPTION, { language: 'th-TH' }));
var en_GB = (Object.assign({}, BASE_OPTION, { language: 'en-GB' }));
var NGQ_DATETIME_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(function () { return NgqDatepickerComponent; }),
    multi: true
};
var NgqDatepickerComponent = /** @class */ (function () {
    function NgqDatepickerComponent() {
        this.propagateChange = function (_) { };
        this.onTouched = function () { };
    }
    Object.defineProperty(NgqDatepickerComponent.prototype, "opts", {
        set: function (opts) {
            this._opts = opts;
            if (this._jQueryElement) {
                this._jQueryElement.datepicker('destroy');
                var newVal = !!this._value
                    ? new Intl.DateTimeFormat(this._opts.language).format(this._value)
                    : '';
                this._jQueryElement.val(newVal);
                this.initDatepicker();
            }
        },
        enumerable: true,
        configurable: true
    });
    NgqDatepickerComponent.prototype.ngAfterViewInit = function () {
        this._jQueryElement = jQuery(this.input.nativeElement);
        this.initDatepicker();
    };
    NgqDatepickerComponent.prototype.initDatepicker = function () {
        var _this = this;
        this._opts = this._opts ? this._opts : th_TH;
        this._jQueryElement.datepicker(this._opts);
        this._jQueryElement.datepicker().on('changeDate', function (e) {
            _this._value = e.date;
            _this.propagateChange(_this._value);
        });
        this._jQueryElement.datepicker('update', this._value);
        this._jQueryElement.prop('disabled', this._isDisabled);
    };
    NgqDatepickerComponent.prototype.onChange = function (value) {
        if (!value) {
            this._value = null;
            this.propagateChange(this._value);
        }
        else {
            if (this._jQueryElement) {
                this._jQueryElement.datepicker('destroy');
                this.initDatepicker();
            }
        }
    };
    NgqDatepickerComponent.prototype.writeValue = function (obj) {
        this._value = obj;
        if (this._jQueryElement) {
            this._jQueryElement.val(this._value);
        }
    };
    NgqDatepickerComponent.prototype.registerOnChange = function (fn) {
        this.propagateChange = fn;
    };
    NgqDatepickerComponent.prototype.registerOnTouched = function (fn) { };
    NgqDatepickerComponent.prototype.setDisabledState = function (isDisabled) {
        this._isDisabled = isDisabled;
        if (this._jQueryElement) {
            this._jQueryElement.prop('disabled', this._isDisabled);
        }
    };
    return NgqDatepickerComponent;
}());
NgqDatepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngq-datepicker',
                template: "<div *ngIf=\"!hideIcon\" class=\"input-group\">\n  <input #input type=\"text\" [attr.class]=\"class\" [attr.id]=\"id\" [attr.placeholder]=\"placeholder\" (change)=\"onChange($event.target.value)\">\n  <div class=\"input-group-addon\" (click)=\"_jQueryElement.datepicker('show')\">\n    <span class=\"glyphicon glyphicon-calendar\"></span>\n  </div>\n</div>\n<input *ngIf=\"hideIcon\" #input type=\"text\" [attr.class]=\"class\" [attr.id]=\"id\" [attr.placeholder]=\"placeholder\" (change)=\"onChange($event.target.value)\">\n",
                styles: [":host{outline:0}"],
                providers: [NGQ_DATETIME_VALUE_ACCESSOR]
            },] },
];
NgqDatepickerComponent.ctorParameters = function () { return []; };
NgqDatepickerComponent.propDecorators = {
    "hideIcon": [{ type: Input },],
    "id": [{ type: Input },],
    "class": [{ type: Input },],
    "placeholder": [{ type: Input },],
    "input": [{ type: ViewChild, args: ['input',] },],
    "opts": [{ type: Input, args: ['opts',] },],
    "onTouched": [{ type: HostListener, args: ['blur',] },],
};
var NgqDatepickerModule = /** @class */ (function () {
    function NgqDatepickerModule() {
    }
    return NgqDatepickerModule;
}());
NgqDatepickerModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [NgqDatepickerComponent],
                exports: [NgqDatepickerComponent]
            },] },
];
NgqDatepickerModule.ctorParameters = function () { return []; };

export { BASE_OPTION, th_TH, en_GB, NgqDatepickerComponent, NgqDatepickerModule };
//# sourceMappingURL=ngq-datepicker.js.map
